@@ -3,7 +3,7 @@
  *
  * MUSCLE SmartCard Development ( http://www.linuxnet.com )
  *
- * Copyright (C) 2003-2004
+ * Copyright (C) 2003-2007
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -20,7 +20,7 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
  *
- * $Id: pcsc_demo.c 2563 2007-06-17 12:10:55Z rousseau $
+ * $Id: pcsc_demo.c 2594 2007-07-02 15:13:08Z rousseau $
  */
 
 #include <stdio.h>
@@ -54,7 +54,7 @@ int main(int argc, char *argv[])
 	LONG rv;
 	SCARDCONTEXT hContext;
 	DWORD dwReaders;
-	LPSTR mszReaders;
+	LPSTR mszReaders = NULL;
 	char *ptr, **readers = NULL;
 	int nbReaders;
 	SCARDHANDLE hCard;
@@ -70,7 +70,7 @@ int main(int argc, char *argv[])
 	DWORD dwSendLength, dwRecvLength;
 
 	printf("PC/SC sample code\n");
-	printf("V 1.2 2003-2005, Ludovic Rousseau <ludovic.rousseau@free.fr>\n");
+	printf("V 1.3 2003-2007, Ludovic Rousseau <ludovic.rousseau@free.fr>\n");
 
 	printf("\nTHIS PROGRAM IS NOT DESIGNED AS A TESTING TOOL FOR END USERS!\n");
 	printf("Do NOT use it unless you really know what you do.\n\n");
@@ -89,11 +89,7 @@ int main(int argc, char *argv[])
 	 * 3. call with the real allocated buffer
 	 */
 	rv = SCardListReaders(hContext, NULL, NULL, &dwReaders);
-	if (rv != SCARD_S_SUCCESS)
-	{
-		printf("SCardListReader: %lX\n", rv);
-		return EXIT_FAILURE;
-	}
+	PCSC_ERROR(rv, "SCardListReaders")
 
 	mszReaders = malloc(sizeof(char)*dwReaders);
 	if (mszReaders == NULL)
@@ -103,8 +99,7 @@ int main(int argc, char *argv[])
 	}
 
 	rv = SCardListReaders(hContext, NULL, mszReaders, &dwReaders);
-	if (rv != SCARD_S_SUCCESS)
-		printf("SCardListReader: %lX\n", rv);
+	PCSC_ERROR(rv, "SCardListReaders")
 
 	/* Extract readers from the null separated string and get the total
 	 * number of readers */
@@ -296,8 +291,10 @@ end:
 			rv);
 
 	/* free allocated memory */
-	free(mszReaders);
-	free(readers);
+	if (mszReaders)
+		free(mszReaders);
+	if (readers)
+		free(readers);
 
 	return EXIT_SUCCESS;
 } /* main */
