@@ -6,7 +6,7 @@
  * Copyright (C) 2004
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: eventhandler.h 2544 2007-05-23 14:19:45Z rousseau $
+ * $Id: eventhandler.h 2639 2007-10-11 08:37:33Z rousseau $
  */
 
 /**
@@ -18,6 +18,8 @@
 #ifndef __eventhandler_h__
 #define __eventhandler_h__
 
+#include <stdint.h>
+
 #ifdef __cplusplus
 extern "C"
 {
@@ -29,15 +31,14 @@ extern "C"
 	 */
 	typedef struct pubReaderStatesList
 	{
-		LONG readerID;
+		int32_t readerID;
 		char readerName[MAX_READERNAME];
-		DWORD readerState;
-		LONG readerSharing;
-		DWORD dummy;
+		uint32_t readerState;
+		int32_t readerSharing;
 
 		UCHAR cardAtr[MAX_ATR_SIZE];
-		DWORD cardAtrLength;
-		DWORD cardProtocol;
+		uint32_t cardAtrLength;
+		uint32_t cardProtocol;
 	}
 	READER_STATE, *PREADER_STATE;
 
