@@ -4,7 +4,7 @@
  * Copyright (C) 2000-2003
  *  David Corcoran <corcoran@linuxnet.com>
  *
- * $Id: hotplug.h 1538 2005-05-26 14:48:00Z rousseau $
+ * $Id: hotplug.h 2310 2007-01-06 21:14:56Z rousseau $
  */
 
 /**
@@ -28,6 +28,7 @@ extern "C"
 #define PCSCLITE_HP_PRODKEY_NAME	"ifdProductID"
 #define PCSCLITE_HP_NAMEKEY_NAME	"ifdFriendlyName"
 #define PCSCLITE_HP_LIBRKEY_NAME	"CFBundleExecutable"
+#define PCSCLITE_HP_CPCTKEY_NAME	"ifdCapabilities"
 
 #define PCSCLITE_HP_BASE_PORT		0x200000
 
@@ -35,6 +36,7 @@ extern "C"
 	ULONG HPRegisterForHotplugEvents(void);
 	LONG HPStopHotPluggables(void);
 	void HPReCheckSerialReaders(void);
+	int SendHotplugSignal(void);
 
 #ifdef __cplusplus
 }
