@@ -6,7 +6,7 @@
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *  David Corcoran <corcoran@linuxnet.com>
  *
- * $Id: hotplug_macosx.c 2151 2006-09-06 20:02:47Z rousseau $
+ * $Id: hotplug_macosx.c 2494 2007-03-27 12:17:53Z rousseau $
  */
 
 /**
@@ -16,7 +16,7 @@
 
 #include "config.h"
 #include "misc.h"
-#include "pcsclite.h"
+#include "pcscd.h"
 
 #if defined(__APPLE__) && !defined(HAVE_LIBUSB)
 #include <CoreFoundation/CoreFoundation.h>
