@@ -6,7 +6,7 @@
  * Copyright (C) 1999-2007
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: pcscdaemon.c 2598 2007-07-05 10:04:08Z rousseau $
+ * $Id: pcscdaemon.c 2720 2008-01-03 15:13:55Z rousseau $
  */
 
 /**
@@ -55,6 +55,7 @@
 
 char AraKiri = FALSE;
 static char Init = TRUE;
+static int ExitValue = EXIT_SUCCESS;
 int HPForceReaderPolling = 0;
 
 /*
@@ -113,7 +114,7 @@ void SVCServiceRunLoop(void)
 {
 	int rsp;
 	LONG rv;
-	DWORD dwClientID;	/* Connection ID used to reference the Client */
+	uint32_t dwClientID;	/* Connection ID used to reference the Client */
 
 	rsp = 0;
 	rv = 0;
@@ -374,7 +375,7 @@ int main(int argc, char **argv)
 		{
 			if (HotPlug)
 			{
-				Log1(PCSC_LOG_CRITICAL, "file " USE_RUN_PID " do not exist");
+				Log1(PCSC_LOG_CRITICAL, "file " PCSCLITE_RUN_PID " do not exist");
 				Log1(PCSC_LOG_CRITICAL, "Hotplug failed");
 				return EXIT_FAILURE;
 			}
@@ -384,7 +385,7 @@ int main(int argc, char **argv)
 			Log1(PCSC_LOG_CRITICAL,
 				"Maybe another pcscd is running?");
 			Log1(PCSC_LOG_CRITICAL,
-				"I can't read process pid from " USE_RUN_PID);
+				"I can't read process pid from " PCSCLITE_RUN_PID);
 			Log1(PCSC_LOG_CRITICAL,
 				"Remove " PCSCLITE_PUBSHM_FILE " and " PCSCLITE_CSOCK_NAME);
 			Log1(PCSC_LOG_CRITICAL,
@@ -417,6 +418,22 @@ int main(int argc, char **argv)
 	signal(SIGINT, signal_trap);
 	signal(SIGHUP, signal_trap);
 
+	/*
+	 * If PCSCLITE_IPC_DIR does not exist then create it
+	 */
+	rv = SYS_Stat(PCSCLITE_IPC_DIR, &fStatBuf);
+	if (rv < 0)
+	{
+		rv = SYS_Mkdir(PCSCLITE_IPC_DIR,
+			S_ISVTX | S_IROTH | S_IXOTH | S_IRGRP | S_IXGRP | S_IRWXU);
+		if (rv != 0)
+		{
+			Log2(PCSC_LOG_CRITICAL,
+				"cannot create " PCSCLITE_IPC_DIR ": %s", strerror(errno));
+			return EXIT_FAILURE;
+		}
+	}
+
 	/*
 	 * Record our pid to make it easier
 	 * to kill the correct pcscd
@@ -424,7 +441,7 @@ int main(int argc, char **argv)
 	{
 		int f;
 
-		if ((f = SYS_OpenFile(USE_RUN_PID, O_RDWR | O_CREAT, 00644)) != -1)
+		if ((f = SYS_OpenFile(PCSCLITE_RUN_PID, O_RDWR | O_CREAT, 00644)) != -1)
 		{
 			char pid[PID_ASCII_SIZE];
 
@@ -434,28 +451,13 @@ int main(int argc, char **argv)
 
 			/* set mode so that the file is world readable.
 			 * The file is used by libpcsclite */
-			SYS_Chmod(USE_RUN_PID, 0644);
+			SYS_Chmod(PCSCLITE_RUN_PID, 0644);
 		}
 		else
-			Log2(PCSC_LOG_CRITICAL, "cannot create " USE_RUN_PID ": %s",
+			Log2(PCSC_LOG_CRITICAL, "cannot create " PCSCLITE_RUN_PID ": %s",
 				strerror(errno));
 	}
 
-	/*
-	 * If PCSCLITE_IPC_DIR does not exist then create it
-	 */
-	rv = SYS_Stat(PCSCLITE_IPC_DIR, &fStatBuf);
-	if (rv < 0)
-	{
-		rv = SYS_Mkdir(PCSCLITE_IPC_DIR, S_ISVTX | S_IRWXO | S_IRWXG | S_IRWXU);
-		if (rv != 0)
-		{
-			Log2(PCSC_LOG_CRITICAL,
-				"cannot create " PCSCLITE_IPC_DIR ": %s", strerror(errno));
-			return EXIT_FAILURE;
-		}
-	}
-
 	/* cleanly remove /var/run/pcsc.* files when exiting */
 	if (atexit(at_exit))
 		Log2(PCSC_LOG_CRITICAL, "atexit() failed: %s", strerror(errno));
@@ -475,6 +477,7 @@ int main(int argc, char **argv)
 		{
 			Log3(PCSC_LOG_CRITICAL, "invalid file %s: %s", newReaderConfig,
 				strerror(errno));
+			ExitValue = EXIT_FAILURE;
 			at_exit();
 		}
 	}
@@ -494,7 +497,10 @@ int main(int argc, char **argv)
 		else
 #endif
 			if (rv == -1)
+			{
+				ExitValue = EXIT_FAILURE;
 				at_exit();
+			}
 	}
 
 	/*
@@ -533,7 +539,7 @@ void at_exit(void)
 
 	clean_temp_files();
 
-	SYS_Exit(EXIT_SUCCESS);
+	SYS_Exit(ExitValue);
 }
 
 void clean_temp_files(void)
@@ -550,9 +556,9 @@ void clean_temp_files(void)
 		Log2(PCSC_LOG_ERROR, "Cannot unlink " PCSCLITE_CSOCK_NAME ": %s",
 			strerror(errno));
 
-	rv = SYS_Unlink(USE_RUN_PID);
+	rv = SYS_Unlink(PCSCLITE_RUN_PID);
 	if (rv != 0)
-		Log2(PCSC_LOG_ERROR, "Cannot unlink " USE_RUN_PID ": %s",
+		Log2(PCSC_LOG_ERROR, "Cannot unlink " PCSCLITE_RUN_PID ": %s",
 			strerror(errno));
 }
 
@@ -602,7 +608,7 @@ void print_usage (char const * const progname)
 	printf("  -f, --foreground	run in foreground (no daemon),\n");
 	printf("			send logs to stderr instead of syslog\n");
 	printf("  -h, --help		display usage information\n");
-	printf("  -H, --hotplug		ask the daemon to rescan the avaiable readers\n");
+	printf("  -H, --hotplug		ask the daemon to rescan the available readers\n");
 	printf("  -v, --version		display the program version number\n");
 	printf("  -d, --debug	 	display lower level debug messages\n");
 	printf("      --info	 	display info level debug messages (default level)\n");
@@ -615,7 +621,7 @@ void print_usage (char const * const progname)
 	printf("  -f	run in foreground (no daemon), send logs to stderr instead of syslog\n");
 	printf("  -d 	display debug messages. Output may be:\n");
 	printf("  -h 	display usage information\n");
-	printf("  -H	ask the daemon to rescan the avaiable readers\n");
+	printf("  -H	ask the daemon to rescan the available readers\n");
 	printf("  -v 	display the program version number\n");
 #endif
 }
