@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: readerfactory.c 2561 2007-06-13 12:48:12Z rousseau $
+ * $Id: readerfactory.c 2636 2007-10-11 08:15:43Z rousseau $
  */
 
 /**
@@ -48,6 +48,8 @@ static DWORD dwNumReadersContexts = 0;
 static char *ConfigFile = NULL;
 static int ConfigFileCRC = 0;
 
+#define IDENTITY_SHIFT 16
+
 LONG RFAllocateReaderSpace(void)
 {
 	int i;   					/* Counter */
@@ -78,11 +80,11 @@ LONG RFAddReader(LPSTR lpcReader, DWORD dwPort, LPSTR lpcLibrary, LPSTR lpcDevic
 	if ((lpcReader == NULL) || (lpcLibrary == NULL) || (lpcDevice == NULL))
 		return SCARD_E_INVALID_VALUE;
 
-	/* Reader name too long? */
-	if (strlen(lpcReader) >= MAX_READERNAME)
+	/* Reader name too long? also count " 00 00"*/
+	if (strlen(lpcReader) > MAX_READERNAME - sizeof(" 00 00"))
 	{
 		Log3(PCSC_LOG_ERROR, "Reader name too long: %d chars instead of max %d",
-			strlen(lpcReader), MAX_READERNAME);
+			strlen(lpcReader), MAX_READERNAME - sizeof(" 00 00"));
 		return SCARD_E_INVALID_VALUE;
 	}
 
@@ -174,7 +176,7 @@ LONG RFAddReader(LPSTR lpcReader, DWORD dwPort, LPSTR lpcLibrary, LPSTR lpcDevic
 	(sReadersContexts[dwContext])->pdwFeeds = NULL;
 	(sReadersContexts[dwContext])->pdwMutex = NULL;
 	(sReadersContexts[dwContext])->dwIdentity =
-		(dwContext + 1) << (sizeof(DWORD) / 2) * 8;
+		(dwContext + 1) << IDENTITY_SHIFT;
 	(sReadersContexts[dwContext])->readerState = NULL;
 
 	for (i = 0; i < PCSCLITE_MAX_READER_CONTEXT_CHANNELS; i++)
@@ -390,7 +392,7 @@ LONG RFAddReader(LPSTR lpcReader, DWORD dwPort, LPSTR lpcLibrary, LPSTR lpcDevic
 		(sReadersContexts[dwContextB])->LockCount = 0;
 		(sReadersContexts[dwContextB])->readerState = NULL;
 		(sReadersContexts[dwContextB])->dwIdentity =
-			(dwContextB + 1) << (sizeof(DWORD) / 2) * 8;
+			(dwContextB + 1) << IDENTITY_SHIFT;
 
 		for (i = 0; i < PCSCLITE_MAX_READER_CONTEXT_CHANNELS; i++)
 			(sReadersContexts[dwContextB])->psHandles[i].hCard = 0;
@@ -803,8 +805,8 @@ LONG RFReaderInfoById(DWORD dwIdentity, PREADER_CONTEXT * sReader)
 	/*
 	 * Strip off the lower nibble and get the identity
 	 */
-	dwIdentity = dwIdentity >> (sizeof(DWORD) / 2) * 8;
-	dwIdentity = dwIdentity << (sizeof(DWORD) / 2) * 8;
+	dwIdentity = dwIdentity >> IDENTITY_SHIFT;
+	dwIdentity = dwIdentity << IDENTITY_SHIFT;
 
 	for (i = 0; i < PCSCLITE_MAX_READERS_CONTEXTS; i++)
 	{
@@ -822,7 +824,8 @@ LONG RFLoadReader(PREADER_CONTEXT rContext)
 {
 	if (rContext->vHandle != 0)
 	{
-		Log1(PCSC_LOG_INFO, "Warning library pointer not NULL");
+		Log2(PCSC_LOG_INFO, "Reusing already loaded driver for %s",
+			rContext->lpcLibrary);
 		/*
 		 * Another reader exists with this library loaded
 		 */
