@@ -6,7 +6,7 @@
  * Copyright (C) 1999
  *  David Corcoran <corcoran@linuxnet.com>
  *
- * $Id: sys_unix.c 2353 2007-01-23 10:31:50Z rousseau $
+ * $Id: sys_unix.c 2403 2007-02-19 09:16:29Z rousseau $
  */
 
 /**
@@ -105,8 +105,10 @@ INTERNAL int SYS_USleep(int iTimeVal)
 
 	return nanosleep(&mrqtp, NULL);
 #else
-	usleep(iTimeVal);
-	return iTimeVal;
+	struct timeval tv;
+	tv.tv_sec  = iTimeVal/1000000;
+	tv.tv_usec = iTimeVal - (tv.tv_sec * 1000000);
+	return select(0, NULL, NULL, NULL, &tv);
 #endif
 }
 
