@@ -6,7 +6,7 @@
  * Copyright (C) 2004-2006
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: testpcsc.c 2541 2007-05-23 07:34:42Z rousseau $
+ * $Id: testpcsc.c 2706 2007-11-17 20:01:43Z rousseau $
  */
 
 /**
@@ -27,8 +27,8 @@
 #define DONT_PANIC 1
 #define RED_PRINTF_FORMAT "\33[01;31m%s\33[0m\n"
 
-void test_rv(int rv, SCARDCONTEXT hContext, int dont_panic);
-void test_rv(int rv, SCARDCONTEXT hContext, int dont_panic)
+void test_rv(LONG rv, SCARDCONTEXT hContext, int dont_panic);
+void test_rv(LONG rv, SCARDCONTEXT hContext, int dont_panic)
 {
 	if (rv != SCARD_S_SUCCESS)
 	{
@@ -112,7 +112,7 @@ int main(int argc, char **argv)
 wait_for_card_again:
 	printf("Testing SCardListReaders\t: ");
 
-	mszGroups = 0;
+	mszGroups = NULL;
 	rv = SCardListReaders(hContext, mszGroups, 0, &dwReaders);
 	test_rv(rv, hContext, PANIC);
 
@@ -181,7 +181,7 @@ wait_for_card_again:
 	}
 
 	/* APDU select file */
-	printf("Select file: ");
+	printf("Select file:");
 	send_length = 7;
 	memcpy(bSendBuffer, "\x00\xA4\x00\x00\x02\x3F\x00", send_length);
 	for (i=0; i<send_length; i++)
@@ -213,7 +213,7 @@ wait_for_card_again:
 
 		rv = SCardControl(hCard, SCARD_CTL_CODE(1), buffer, 1, buffer,
 			sizeof(buffer), &cbRecvLength);
-		if (cbRecvLength)
+		if (cbRecvLength && (SCARD_S_SUCCESS == rv))
 		{
 			for (i=0; i<cbRecvLength; i++)
 				printf("%c", buffer[i]);
@@ -272,8 +272,8 @@ wait_for_card_again:
 
 	printf("Testing SCardStatus\t\t: ");
 
-	dwReaderLen = 50;
-	pcReaders   = malloc(sizeof(char) * 50);
+	dwReaderLen = 100;
+	pcReaders   = malloc(sizeof(char) * 100);
 	dwAtrLen    = MAX_ATR_SIZE;
 
 	rv = SCardStatus(hCard, pcReaders, &dwReaderLen, &dwState, &dwProt,
