@@ -6,7 +6,7 @@
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: thread_generic.h 2559 2007-06-13 12:44:36Z rousseau $
+ * $Id: thread_generic.h 2654 2007-10-16 14:23:20Z rousseau $
  */
 
 /**
@@ -51,7 +51,7 @@ extern "C"
 	int SYS_MutexLock(PCSCLITE_MUTEX_T);
 	int SYS_MutexUnLock(PCSCLITE_MUTEX_T);
 	int SYS_ThreadCreate(PCSCLITE_THREAD_T *, int, PCSCLITE_THREAD_FUNCTION( ), LPVOID);
-	int SYS_ThreadCancel(PCSCLITE_THREAD_T *);
+	int SYS_ThreadCancel(PCSCLITE_THREAD_T);
 	int SYS_ThreadDetach(PCSCLITE_THREAD_T);
 	int SYS_ThreadJoin(PCSCLITE_THREAD_T *, LPVOID*);
 	int SYS_ThreadExit(LPVOID);
