@@ -5,7 +5,7 @@
  *  David Corcoran <corcoran@linuxnet.com>
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *
- * $Id: winscard_svc.h 1421 2005-04-12 12:09:21Z rousseau $
+ * $Id: winscard_svc.h 2635 2007-10-09 15:01:07Z rousseau $
  */
 
 /**
@@ -22,7 +22,7 @@ extern "C"
 {
 #endif
 	LONG ContextsInitialize(void);
-	LONG CreateContextThread(PDWORD);
+	LONG CreateContextThread(uint32_t *);
 #ifdef __cplusplus
 }
 #endif
